@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional
 
 from mi.actions.admin import AdminActions
 from mi.actions.drive import DriveActions
