@@ -1,4 +1,5 @@
-from mi.framework.http import HTTPSession, Route
+from mi.framework.http import HTTPSession
+from mi.framework.router import Route
 
 
 class AdminAdvertisingManager:
