@@ -2,7 +2,8 @@ from __future__ import annotations
 
 from typing import Optional
 
-from mi.framework.http import HTTPSession, Route
+from mi.framework.http import HTTPSession
+from mi.framework.router import Route
 
 
 class FavoriteManager:
