@@ -2,10 +2,12 @@ from __future__ import annotations
 
 from typing import Optional
 
-from mi.framework.http import HTTPSession, Route
+from mi.framework.http import HTTPSession
 
 
 class NoteManager:
+    """User behavior for notes"""
+
     def __init__(self, note_id: Optional[str] = None):
         self.__note_id = note_id
 
